@@ -10,5 +10,5 @@ utils::globalVariables(c(
   "term", "statistic", "estimate",
   "conf.low", "conf.high", "coef",
   "x", "y", "ord",
-  "iter_id", "h_name"
+  "iter_id", "h_name", "varying_name", "row_unique"
 ))
\ No newline at end of file
