@@ -191,6 +191,12 @@ is.boundbvharemp <- function(x) {
   inherits(x, "boundbvharemp")
 }
 
+#' @rdname is.varlse
+#' @export
+is.interceptspec <- function(x) {
+  inherits(x, "interceptspec")
+}
+
 #' @rdname is.varlse
 #' @export
 is.ssvsinput <- function(x) {
@@ -214,3 +220,9 @@ is.bvharpriorspec <- function(x) {
 is.horseshoespec <- function(x) {
   inherits(x, "horseshoespec")
 }
+
+#' @rdname is.varlse
+#' @export
+is.svspec <- function(x) {
+  inherits(x, "svspec")
+}
