@@ -621,15 +621,13 @@ choose_ssvs <- function(y,
   res <- switch(
     type,
     "VAR" = {
-      fit <- var_lm(y, p = ord, include_mean = include_mean)
-      fit_infer <- infer_var(var_lm(y, p = ord, include_mean = include_mean))$summary_stat
-      # mean_coef <- fit_infer[,1]
+      fit <- var_lm(y, p = ord, include_mean = FALSE)
+      fit_infer <- infer_var(fit)$summary_stat
+      mean_coef <- fit_infer[,1]
       sd_coef <- fit_infer[,2]
-      
       if (include_mean) {
-        id_const <- seq(from = fit$df, to = fit$df * fit$m, by = fit$df)
-        mean_non <- fit_infer[id_const, 1]
-        sd_coef <- fit_infer[-id_const]
+        fit <- var_lm(y, p = ord, include_mean = TRUE)
+        mean_non <- fit$coef[fit$df,]
       }
       sd_chol <- chol(fit$covmat)
       sd_chol <- sd_chol[upper.tri(sd_chol, diag = FALSE)]
@@ -637,6 +635,8 @@ choose_ssvs <- function(y,
         coef_spike = param[1] * sd_coef,
         coef_slab = param[2] * sd_coef,
         coef_mixture = .5,
+        coef_s1 = 1,
+        coef_s2 = 1,
         # mean_coef = mean_coef,
         mean_non = mean_non,
         sd_non = sd_non,
@@ -646,7 +646,9 @@ choose_ssvs <- function(y,
         rate = gamma_param[2],
         chol_spike = param[1] * sd_chol,
         chol_slab = param[2] * sd_chol,
-        chol_mixture = .5
+        chol_mixture = .5,
+        chol_s1 = 1,
+        chol_s2 = 1
       )
     },
     "VHAR" = {
@@ -668,6 +670,8 @@ choose_ssvs <- function(y,
         coef_spike = param[1] * sd_coef,
         coef_slab = param[2] * sd_coef,
         coef_mixture = .5,
+        coef_s1 = 1,
+        coef_s2 = 1,
         # mean_coef = mean_coef,
         mean_non = mean_non,
         sd_non = sd_non,
@@ -677,7 +681,9 @@ choose_ssvs <- function(y,
         rate = gamma_param[2],
         chol_spike = param[1] * sd_chol,
         chol_slab = param[2] * sd_chol,
-        chol_mixture = .5
+        chol_mixture = .5,
+        chol_s1 = 1,
+        chol_s2 = 1
       )
     }
   )
