@@ -149,7 +149,7 @@ Eigen::MatrixXd forecast_bvarssvs(int num_chains, int var_lag, int step,
 		eta_chain = eta_record.middleRows(chain * num_sim, num_sim);
 		psi_chain = psi_record.middleRows(chain * num_sim, num_sim);
 		for (int b = 0; b < num_sim; b++) {
-			density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b), dim);
+			density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b).eval(), dim);
 			chol_factor = bvhar::build_chol(psi_chain.row(b), eta_chain.row(b));
 			sig_cycle = (chol_factor * chol_factor.transpose()).inverse();
 			predictive_distn.block(chain * step, b * dim, 1, dim) = sim_mgaussian_chol(1, density_forecast, sig_cycle);
@@ -166,7 +166,7 @@ Eigen::MatrixXd forecast_bvarssvs(int num_chains, int var_lag, int step,
 			for (int b = 0; b < num_sim; b++) {
 				tmp_vec = last_pvec.head(dim_design - dim);
 				last_pvec << density_forecast, tmp_vec;
-				density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b), dim);
+				density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b).eval(), dim);
 				chol_factor = bvhar::build_chol(psi_chain.row(b), eta_chain.row(b));
 				sig_cycle = (chol_factor * chol_factor.transpose()).inverse();
 				predictive_distn.block(chain * step + i, b * dim, 1, dim) = sim_mgaussian_chol(1, density_forecast, sig_cycle);
@@ -211,7 +211,7 @@ Eigen::MatrixXd forecast_bvarhs(int num_chains, int var_lag, int step,
 		alpha_chain = alpha_record.middleRows(chain * num_sim, num_sim);
 		sig_chain = sigma_record.segment(chain * num_sim, num_sim);
 		for (int b = 0; b < num_sim; b++) {
-			density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b), dim);
+			density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b).eval(), dim);
 			sig_cycle.setIdentity();
 			sig_cycle *= sig_chain[b];
 			predictive_distn.block(chain * step, b * dim, 1, dim) = sim_mgaussian_chol(1, density_forecast, sig_cycle);
@@ -227,7 +227,7 @@ Eigen::MatrixXd forecast_bvarhs(int num_chains, int var_lag, int step,
 			for (int b = 0; b < num_sim; b++) {
 				tmp_vec = last_pvec.head(dim_design - dim);
 				last_pvec << density_forecast, tmp_vec;
-				density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b), dim);
+				density_forecast = last_pvec.transpose() * bvhar::unvectorize(alpha_chain.row(b).eval(), dim);
 				sig_cycle.setIdentity();
 				sig_cycle *= sig_chain[b];
 				predictive_distn.block(chain * step + i, b * dim, 1, dim) = sim_mgaussian_chol(1, density_forecast, sig_cycle);
@@ -317,7 +317,7 @@ Eigen::MatrixXd forecast_bvarsv_density(int num_chains, int var_lag, int step, E
 		a_chain = a_record.middleRows(chain * num_sim, num_sim);
 		sigh_chain = sigh_record.middleRows(chain * num_sim, num_sim);
 		for (int b = 0; b < num_sim; b++) {
-			coef_mat_record.topRows(var_lag * dim) = bvhar::unvectorize(alpha_chain.row(b).head(num_alpha).transpose(), dim);
+			coef_mat_record.topRows(var_lag * dim) = bvhar::unvectorize(alpha_chain.row(b).head(num_alpha).transpose().eval(), dim);
 			if (include_mean) {
 				coef_mat_record.bottomRows(1) = alpha_chain.row(b).tail(dim);
 			}
@@ -348,7 +348,7 @@ Eigen::MatrixXd forecast_bvarsv_density(int num_chains, int var_lag, int step, E
 			for (int b = 0; b < num_sim; b++) {
 				tmp_vec = last_pvec.head(dim_design - dim);
 				last_pvec << density_forecast, tmp_vec;
-				coef_mat_record.topRows(var_lag * dim) = bvhar::unvectorize(alpha_chain.row(b).head(num_alpha).transpose(), dim);
+				coef_mat_record.topRows(var_lag * dim) = bvhar::unvectorize(alpha_chain.row(b).head(num_alpha).transpose().eval(), dim);
 				if (include_mean) {
 					coef_mat_record.bottomRows(1) = alpha_chain.row(b).tail(dim);
 				}
